<?php

namespace Ebizmarts\MageMonkey\Cron;

class UpdateStatusFromMailChimpToMagento {

    protected $_helperMailChimp;

    /**
     * Subscribers collection
     *
     * @var \Magento\Newsletter\Model\ResourceModel\Subscriber\Collection
     */
    protected $_subscribersCollection;
    protected $scopeConfig;
    protected $_loggerCron;

    public function __construct(
    \Magento\Newsletter\Model\ResourceModel\Subscriber\CollectionFactory $subscriberCollectionFactory, \Ebizmarts\MageMonkey\Helper\Import $helperMailchimp, \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig, \Ebizmarts\MageMonkey\Model\Logger\LoggerCron $loggerCron
    ) {
        $this->_helperMailChimp = $helperMailchimp;
        $this->_subscribersCollection = $subscriberCollectionFactory->create();
        $this->scopeConfig = $scopeConfig;
        $this->_loggerCron = $loggerCron;
    }

    public function execute() {

        if ($this->_helperMailChimp->isCronSyncStatusEnabled()) {
            try {

                $this->_loggerCron->info(" #### START CRON UpdateStatusFromMailChimpToMagento #### ");

                $subscribers = $this->_subscribersCollection->addFieldToSelect('subscriber_id')->load();

                $subscriberIds = [];

                foreach ($subscribers as $subscriber) {
                    $subscriberIds[] = $subscriber->getId();
                }

                $this->_loggerCron->info(" #### SUBSCRIBER COUNT -> " . count($subscriberIds) . " #### ");
                
                $updated = $this->_helperMailChimp->syncStatusFromMailChimpToMagento($subscriberIds);
                
                $this->_loggerCron->info(" #### SUBSCRIBER SYNC ON MAGENTO -> " . $updated . " #### ");
                
            } catch (\Exception $e) {
                $this->_loggerCron->info(" #### ERROR -> " . $e->getMessage() . " #### ");
            }
        }
    }

}
